@@ -1,19 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from fasttest.common import log_info
-from fasttest.runner.case_executor import CaseExecutor
+from fasttest.runner.action_analysis import ActionAnalysis
+from fasttest.runner.action_executor import ActionExecutor
 
 class CaseAnalysis(object):
 
     def __init__(self):
-        self.CaseExecutor = CaseExecutor()
+        self.action_executor = ActionExecutor()
+        self.action_nalysis = ActionAnalysis()
 
     def iteration(self, steps):
 
         if isinstance(steps, list):
             for step in steps:
                 if isinstance(step, str):
-                    self.CaseExecutor.case_executor(step)
+                    self.case_executor(step)
                     if step == 'break':
                         return True
                 elif isinstance(step, dict):
@@ -23,12 +24,23 @@ class CaseAnalysis(object):
         elif isinstance(steps, dict):
             for key, values in steps.items():
                 if key.startswith('while'):
-                    while self.CaseExecutor.case_executor(key):
+                    while self.case_executor(key):
                         result = self.iteration(values)
                         if result:
                             break
                 elif key.startswith('if') or key.startswith('elif') or key.startswith('else'):
-                    if self.CaseExecutor.case_executor(key):
+                    if self.case_executor(key):
                         result = self.iteration(values)
                         if result:
-                            return True
\ No newline at end of file
+                            return True
+                        break
+                else:
+                    raise SyntaxError('- {}:'.format(key))
+
+    def case_executor(self, step):
+        action = self.action_nalysis.action_analysis(step)
+        if action:
+            result = self.action_executor.action_executor(action)
+        else:
+            result = None
+        return result
\ No newline at end of file
